<?php

/**
 * CelloSaaS web service proxy class
 */
class CelloProxy
{
    /**
     * Stores the SOAP call options
     * @var array of options
     */
    private $options = null;

    /**
     * Inits the soap call options with auth credentials
     */
    public function __construct(){
        # if not logged in use default api key (occurs on first time validating a user)
        $tenant_id = empty($_SESSION['tenant_id']) ? 'b590cd25-3093-df11-8deb-001ec9dab123' : $_SESSION['tenant_id'];
        $username = empty($_SESSION['user_name']) ? 'admin@company.com' : $_SESSION['user_name'];
        $api_key = empty( $_SESSION['api_key']) ? 'UBd2DX9xIPprqtB7D0yb0w==' : $_SESSION['api_key'];
        
        $login = $tenant_id.'/'.$username;       
        
        # Uses HTTP Basic auth, basicHttpbinding, SOAP version 1.1
        $this->options = array(
            'login' => $login,
            'password' => $api_key,
            'default_socket_timeout' => 30,
            'soap_version'=>SOAP_1_1,
            'exceptions'=>true,
            'trace'=>1,
            'cache_wsdl'=>WSDL_CACHE_NONE # for testing wsdl cache is disabled
         );
    }
    
    /**
     * Get tenant details for the given tenant_id
     * @param string $tenant_id 
     * @return Tenant object
     */
    function get_tenant_details_by_id($tenant_id){
        $url = 'http://localhost:444/TenantManagement/TenantService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("tenantId"=>$tenant_id);
        $result = $client->GetTenantDetailsByTenantId($args)->GetTenantDetailsByTenantIdResult;
        
        return $result;
    }
    
    /**
     * Get all settings for the given tenant 
     * @param string $tenant_id 
     * @return array of key value pair
     */
    function get_tenant_settings($tenant_id){
        $url = 'http://localhost:444/SettingsManagement/TenantSettingsService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("tenantId"=>$tenant_id);
        $result = $client->GetTenantSettings($args)->GetTenantSettingsResult;
        
        return $result->Setting->Attributes->KeyValueOfstringstring;
    }
    
	/**
	 * Fetchs the api key for the given tenant 
	 * @param string $tenant_id 
	 * @return string
	 */
	function get_api_key($tenant_id){        
        $settings = $this->get_tenant_settings($tenant_id);
        
        if($settings==null) return null;
        
        $key = null;
        
        foreach ($settings as $item)
        {
            if($item->Key == 'WCFSharedKey'){
                $key = $item->Value;
                break;
            }
        }

        return $key;
    }
    
    /**
     * Get user details by user name
     * @param string $username 
     * @param string $companyCode 
     * @return userdetails object if found
     */
    function get_user_details_by_username($username,$companyCode){
        $url = 'http://localhost:444/UserManagement/UserDetailsService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("userName"=>$username,"companyCode"=>$companyCode);
        $userDetails = $client->GetUserDetailsByCompanyCodeAndUserName($args)->GetUserDetailsByCompanyCodeAndUserNameResult;
        return $userDetails;
    }
    
    /**
     * Get user details by user id
     * @param uuid $user_id 
     * @return user object
     */
    function get_user_details_by_id($user_id){
        $url = 'http://localhost:444/UserManagement/UserDetailsService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("userId"=>$user_id);
        $userDetails = $client->GetUserDetailsByUserId($args)->GetUserDetailsByUserIdResult;
        return $userDetails;
    }
    
    /**
     * Validates the username and password
     * @param string $username 
     * @param string $password 
     * @param string $companyCode 
     * @return true or false
     */
    function validate_user($username,$password,$companyCode){
        $url = 'http://localhost:444/UserManagement/UserDetailsService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("userName"=>$username,"password"=>$password,"companyCode"=>$companyCode);
        $result = $client->ValidateUserWithCompanyCode($args);

        return $result->ValidateUserWithCompanyCodeResult == 1;
    }
    
    /**
     * Fetchs the user roles
     * @param string $user_id 
     * @return array of user roles (string) [Example: array("GR$Sales","GR$Manager")]
     */
    function get_user_roles($user_id){
        $url = 'http://localhost:444/AccessControlManagement/RoleService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("userIdentifier"=>$user_id);
        $result = $client->GetUserRoles($args);
        $roles = $result->GetUserRolesResult->string;
        
        if($roles==null || count($roles) == 0){
            return array();
        }
        
        if(!is_array($roles)){
            $roles = array($roles);
        }
        
        return $roles;
    }
    
    /**
     * Fetchs the user privileges
     * @param string $user_id 
     * @return array of user privileges
     */
    function get_user_privileges($user_id){
        $roles = $this->get_user_roles($user_id);
        
        if(count($roles) == 0){
            return array();
        }
        
        $url = 'http://localhost:444/AccessControlManagement/PrivilegeService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("roleIdentifiers"=> $roles);
        $result = $client->GetPrivilegesForRoles($args);
        return $result->GetPrivilegesForRolesResult->KeyValueOfstringRolePrivilegeZscSInth;
    }
    
    /**
     * Gets the tenant license details
     * @param string $tenant_id 
     * @return TenantLicense object
     */
    function get_tenant_license($tenant_id){
        $url = 'http://localhost:444/LicenseManagement/LicenseService.svc?singleWsdl';
        $client = new SoapClient($url, $this->options);
        $client->soap_defencoding = 'UTF-8';

        $args = array("tenantId"=>$tenant_id);
        $result = $client->GetTenantLicense($args)->GetTenantLicenseResult;
        
        return $result;
    }
}

?>