<?php
error_reporting(E_ALL);
session_start();

require_once('autoload.php');

if(isset($_SESSION['user_id']))
{
    #if already logged in successfully goto home page
    header('Location: home.php');
    exit();
}

$error='';
$companyCode = '';
$username = '';
$password = '';

if (isset($_POST['submit'])) {
    #validate inputs
    $companyCode = $_POST['companyCode'];
    $username = $_POST['username'];
    $password = $_POST['password'];

    if(empty($companyCode)){
        $error .= '<p>Please enter company code';
    }

    if(empty($username)){
        $error .= '<p>Please enter username';
    }

    if(empty($password)){
        $error .= '<p>Please enter password';
    }

    if($error == ''){
        try {
            #create webservice client
            $client = new CelloProxy();
            #validate the given credentials against cellosaas authentication service
            $valid = $client->validate_user($username,$password,$companyCode); #here default api key will be used

            if($valid){
                #valid credentials provided so get the username
                $userDetails = $client->get_user_details_by_username($username,$companyCode); #here default api key will be used

                if($userDetails!=null){
                    $tenant_id = $userDetails->MembershipDetails->TenantCode;
                    $api_key = $client->get_api_key($tenant_id);

                    if(!empty($api_key)) {
                        #fill required session values
                        $_SESSION['user_id'] = $userDetails->User->UserId;
                        $_SESSION['tenant_id'] = $userDetails->MembershipDetails->TenantCode;
                        $_SESSION['user_name'] = $userDetails->MembershipDetails->UserName;
                        $_SESSION['api_key'] = $api_key;

                        header('Location: home.php'); #goto home page
                        exit;
                    }else{
                        $error = "API key not available for this tenant!";
                    }
                }else{
                    $error = "Invalid username or password!";
                }
            }else{
                $error = "Invalid username or password!";
            }
        }
        catch(SoapFault $fault){
            $error = $fault->faultstring;
        }
    }
}

?>

<!doctype html>
<!--[if lt IE 7]> <html class="no-js lt-ie9 lt-ie8 lt-ie7" lang="en"> <![endif]-->
<!--[if IE 7]>    <html class="no-js lt-ie9 lt-ie8" lang="en"> <![endif]-->
<!--[if IE 8]>    <html class="no-js lt-ie9" lang="en"> <![endif]-->
<!--[if gt IE 8]><!-->
<html class="no-js" lang="en">
<!--<![endif]-->
<head id="head1">
    <meta charset="utf-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />
    <meta name="viewport" content="width=device-width" />
    <link rel="shortcut icon" href="/favicon.ico" />
    <title>Login To CelloSaaS
    </title>
    <link rel="stylesheet" type="text/css" href="/App_Themes/CelloSkin/bootstrap.css" />
    <link rel="stylesheet" type="text/css" href="/App_Themes/CelloSkin/custom-theme.css" />
    <link rel="stylesheet" type="text/css" href="/App_Themes/CelloSkin/font-awesome.min.css" />
    <link rel="stylesheet" type="text/css" href="/App_Themes/CelloSkin/prettify.css" />
    <style>
        html, body {
            height: 100%;
            overflow: auto;
        }
    </style>
</head>
<body class="login">

    <section id="content" class="m-t-lg wrapper-md animated fadeInUp">
        <header>
            <div class="container">
                <div class="row">
                    <div class="col-md-4 col-md-offset-4">
                        <div id="logo">
                            <a href="/" title="Goto CelloSaaS Login Page">
                                <h1>Cello
                                    <span class="semi-bold">SaaS</span>
                                </h1>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </header>
    </section>
    <section id="login" class="visible animated fadeInDown">
        <div class="container">
            <div class="row">
                <div class="col-md-4 col-md-offset-4 col-np">
                    <?php
                    if(isset($error) && $error != ''){
                    ?>
                    <div class='alert alert-danger'>
                        <?php echo $error ?>
                    </div>
                    <?php
                    }
                    ?>
                    <div class="login-box-plain">
                        <h2 class="bigintro">Login</h2>
                        <div class="divide-20"></div>
                        <form action="" method="post">
                            <div class="form-group ">
                                <label for="companyCode">Company Code</label>
                                <i class="fa fa-cloud"></i>
                                <input class="form-control" id="companyCode" name="companyCode" placeholder="company" type="text" value="<?php echo $companyCode ?>" />
                            </div>

                            <div class="form-group ">
                                <label for="username">User Name</label>
                                <i class="fa fa-user"></i>
                                <input class="form-control" id="username" name="username" placeholder="john.smith" type="text" value="<?php echo $username ?>" />
                            </div>
                            <div class="form-group ">
                                <label for="password">Password</label>
                                <i class="fa fa-lock"></i>
                                <input class="form-control" id="password" name="password" placeholder="password" type="password" />
                            </div>
                            <div class="form-actions">
                                <button class="btn btn-primary btn-block" name="submit" type="submit">Submit</button>
                            </div>
                        </form>
                        <div class="divide-20"></div>
                        <div class="login-helpers">
                            <a href="#" id="view-src" title="View php source for login!">View source
                            </a>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </section>
    <div class="modal fade" id="login-source" tabindex="-1" role="dialog" aria-labelledby="login-source" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content" style="width: 1000px; left: -38%;">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-hidden="true">
                        &times;</button>
                    <h4 class="modal-title">Login PHP Source</h4>
                </div>
                <div class="modal-body" style="height:700px;overflow:auto;">
                    <pre class="prettyprint"><?php
                                             $src = file_get_contents(__FILE__);
                                             echo htmlspecialchars($src);
                                             ?></pre>
                </div>
                <div class="modal-footer">
                    <div class="actions">
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="/Scripts/jquery.min.js" type="text/javascript"></script>
    <script src="/Scripts/bootstrap.min.js" type="text/javascript"></script>
    <script src="/Scripts/prettify.js" type="text/javascript"></script>
    <script type="text/javascript">
        $(function () {
            if ($('#companyCode').val() == '') {
                $('#companyCode').focus();
                $('#companyCode').select();
            } else if ($('#username').val() == '') {
                $('#username').focus();
                $('#username').select();
            } else if ($('#password').val() == '') {
                $('#password').focus();
            } else {
                $('#username').select();
                $('#username').focus();
            }

            $('#login-source').modal({ "show": false });

            $('#view-src').click(function () {
                $('#login-source').modal("show");
            });

            window.prettyPrint && prettyPrint()
        });
    </script>
</body>
</html>
